==> igniteui-react-charts-16.6.8.tgz: package/ES5/FinancialOverlay.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { FinancialSeries } from "./FinancialSeries";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { ISortingAxis_$type } from "./ISortingAxis";
import { Type, typeCast, markType } from "igniteui-react-core/ES5/type";
import { Rect } from "igniteui-react-core/ES5/Rect";
import { ScalerParams } from "./ScalerParams";
import { AxisRange } from "./AxisRange";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
import { isNaN_ } from "igniteui-react-core/ES5/number";
/**
 * @hidden
 */
var FinancialOverlay = /** @class */ (function (_super) {
    tslib_1.__extends(FinancialOverlay, _super);
    function FinancialOverlay() {
        var _this = _super.call(this) || this;
        _this.pb = false;
        _this.pb = false;
        return _this;
    }
    FinancialOverlay.prototype.hs = function (a, b, c, d) {
        _super.prototype.hs.call(this, a, b, c, d);
        if (this.l1 != null && typeCast(ISortingAxis_$type, this.l1) !== null) {
            this.l1.i$i();
        }
        this.mh.bu.e(this.er);
        this.pc();
        if (this.mm != null) {
            this.mm.ck();
        }
        this.i6(true);
    };
    FinancialOverlay.prototype.get_du = function () {
        return true;
    };
    FinancialOverlay.prototype.is = function (a, b, c, d) {
        switch (b) {
            case "FastItemsSource":
                this.pb = false;
                break;
            case FinancialOverlay.$$p[0]:
                this.pb = false;
                this.i6(false);
                this.ic();
                break;
            case "XAxis":
                this.pb = false;
                break;
        }
        _super.prototype.is.call(this, a, b, c, d);
    };
    FinancialOverlay.prototype.bd = function () {
        if (this.be == 0) {
            return 1;
        }
        else {
            return _super.prototype.bd.call(this);
        }
    };
    FinancialOverlay.prototype.dg = function (a, b) {
        if (this.df(a, b)) {
            return true;
        }
        return false;
    };
    FinancialOverlay.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.i6(false);
    };
    FinancialOverlay.prototype.c8 = function (a) {
        var b = this.bz != null ? this.bz.indexOf(a) : -1;
        var c = this.bi.bs;
        c = c.copy();
        var d = this.bi.br;
        var e = new Rect(0, 0, 0, 1, 1);
        var f = this.ll(this.bi);
        var g = new ScalerParams(0, e, e, this.l1.b8, f);
        var h = new ScalerParams(0, e, e, this.mm.b8, f);
        h.b = this.ee();
        if (b >= 0 && Rect.l_op_Inequality(c, null) && Rect.l_op_Inequality(d, null)) {
            if (this.l1 != null) {
                var i = this.l1.dt(b, g);
                if (i < c.left + 0.1 * c.width) {
                    i = i + 0.4 * c.width;
                }
                if (i > c.right - 0.1 * c.width) {
                    i = i - 0.4 * c.width;
                }
                c.x = i - 0.5 * c.width;
            }
            if (this.mm != null && this.mt != null && this.mr != null && b < this.mt.count && b < this.mr.count) {
                var j = this.mm.dt(this.mt.item(b), h);
                var k = this.mm.dt(this.mr.item(b), h);
                if (!isNaN_(j) && !isNaN_(k)) {
                    var l = Math.abs(j - k);
                    if (c.height < l) {
                        c.height = l;
                        c.y = Math.min(j, k);
                    }
                    else {
                        if (j < c.top + 0.1 * c.height) {
                            j = j + 0.4 * c.height;
                        }
                        if (j > c.bottom - 0.1 * c.height) {
                            j = j - 0.4 * c.height;
                        }
                        c.y = j - 0.5 * c.height;
                    }
                }
            }
            this.bn.ap(this.bs, c, true);
        }
        return b >= 0;
    };
    FinancialOverlay.prototype.an = function (a) {
        if (a != null && a == this.mm && this.mt != null && this.mr != null) {
            return new AxisRange(this.mt.minimum, this.mr.maximum);
        }
        return null;
    };
    FinancialOverlay.$t = markType(FinancialOverlay, 'FinancialOverlay', FinancialSeries.$);
    return FinancialOverlay;
}(FinancialSeries));
export { FinancialOverlay };
Type.dep(DependencyProperty, PropertyMetadata, FinancialOverlay, 'raisePropertyChanged', ['IgnoreFirst:pd:pf', [1, 0]]);

==> igniteui-react-charts-16.11.1.tgz: package/ES5/FinancialOverlay.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { FinancialSeries } from "./FinancialSeries";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { ISortingAxis_$type } from "./ISortingAxis";
import { Type, typeCast, markType } from "igniteui-react-core/ES5/type";
import { Rect } from "igniteui-react-core/ES5/Rect";
import { ScalerParams } from "./ScalerParams";
import { AxisRange } from "./AxisRange";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
import { isNaN_ } from "igniteui-react-core/ES5/number";
/**
 * @hidden
 */
var FinancialOverlay = /** @class */ (function (_super) {
    tslib_1.__extends(FinancialOverlay, _super);
    function FinancialOverlay() {
        var _this = _super.call(this) || this;
        _this.pi = false;
        _this.pi = false;
        return _this;
    }
    FinancialOverlay.prototype.hy = function (a, b, c, d) {
        _super.prototype.hy.call(this, a, b, c, d);
        if (this.l8 != null && typeCast(ISortingAxis_$type, this.l8) !== null) {
            this.l8.i$i();
        }
        this.mo.bu.e(this.eu);
        this.pj();
        if (this.mt != null) {
            this.mt.cl();
        }
        this.jd(true);
    };
    FinancialOverlay.prototype.get_dv = function () {
        return true;
    };
    FinancialOverlay.prototype.iz = function (a, b, c, d) {
        switch (b) {
            case "FastItemsSource":
                this.pi = false;
                break;
            case FinancialOverlay.$$p[0]:
                this.pi = false;
                this.jd(false);
                this.ik();
                break;
            case "XAxis":
                this.pi = false;
                break;
        }
        _super.prototype.iz.call(this, a, b, c, d);
    };
    FinancialOverlay.prototype.bd = function () {
        if (this.be == 0) {
            return 1;
        }
        else {
            return _super.prototype.bd.call(this);
        }
    };
    FinancialOverlay.prototype.dh = function (a, b) {
        if (this.dg(a, b)) {
            return true;
        }
        return false;
    };
    FinancialOverlay.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.jd(false);
    };
    FinancialOverlay.prototype.c9 = function (a) {
        var b = this.bz != null ? this.bz.indexOf(a) : -1;
        var c = this.bi.bs;
        c = c.copy();
        var d = this.bi.br;
        var e = new Rect(0, 0, 0, 1, 1);
        var f = this.ls(this.bi);
        var g = new ScalerParams(0, e, e, this.l8.b8, f);
        var h = new ScalerParams(0, e, e, this.mt.b8, f);
        h.b = this.eh();
        if (b >= 0 && Rect.l_op_Inequality(c, null) && Rect.l_op_Inequality(d, null)) {
            if (this.l8 != null) {
                var i = this.l8.dw(b, g);
                if (i < c.left + 0.1 * c.width) {
                    i = i + 0.4 * c.width;
                }
                if (i > c.right - 0.1 * c.width) {
                    i = i - 0.4 * c.width;
                }
                c.x = i - 0.5 * c.width;
            }
            if (this.mt != null && this.m0 != null && this.my != null && b < this.m0.count && b < this.my.count) {
                var j = this.mt.dw(this.m0.item(b), h);
                var k = this.mt.dw(this.my.item(b), h);
                if (!isNaN_(j) && !isNaN_(k)) {
                    var l = Math.abs(j - k);
                    if (c.height < l) {
                        c.height = l;
                        c.y = Math.min(j, k);
                    }
                    else {
                        if (j < c.top + 0.1 * c.height) {
                            j = j + 0.4 * c.height;
                        }
                        if (j > c.bottom - 0.1 * c.height) {
                            j = j - 0.4 * c.height;
                        }
                        c.y = j - 0.5 * c.height;
                    }
                }
            }
            this.bn.ap(this.bs, c, true);
        }
        return b >= 0;
    };
    FinancialOverlay.prototype.an = function (a) {
        if (a != null && a == this.mt && this.m0 != null && this.my != null) {
            return new AxisRange(this.m0.minimum, this.my.maximum);
        }
        return null;
    };
    FinancialOverlay.$t = markType(FinancialOverlay, 'FinancialOverlay', FinancialSeries.$);
    return FinancialOverlay;
}(FinancialSeries));
export { FinancialOverlay };
Type.dep(DependencyProperty, PropertyMetadata, FinancialOverlay, 'raisePropertyChanged', ['IgnoreFirst:pk:pm', [1, 0]]);
